@@ -1,4 +1,4 @@
-(* $Id: fusion.ml 6943 2015-05-01 10:53:21Z msekulla $
+(* $Id: fusion.ml 7377 2015-11-20 15:59:02Z jr_reuter $
 
    Copyright (C) 1999-2015 by
 
@@ -7,7 +7,7 @@
        Juergen Reuter <juergen.reuter@desy.de>
        with contributions from
        Christian Speckner <cnspeckn@googlemail.com>
-       Marco Sekulla <sekulla@physik.uni-siegen.de>
+       Marco Sekulla <marco.sekulla@kit.edu>
 
    WHIZARD is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
@@ -24,9 +24,9 @@
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  *)
 
 let rcs_file = RCS.parse "Fusion" ["General Fusions"]
-    { RCS.revision = "$Revision: 6943 $";
-      RCS.date = "$Date: 2015-05-01 12:53:21 +0200 (Fri, 01 May 2015) $";
-      RCS.author = "$Author: msekulla $";
+    { RCS.revision = "$Revision: 7377 $";
+      RCS.date = "$Date: 2015-11-20 16:59:02 +0100 (Fri, 20 Nov 2015) $";
+      RCS.author = "$Author: jr_reuter $";
       RCS.source
         = "$URL: svn+ssh://jr_reuter@login.hepforge.org/hepforge/svn/whizard/trunk/omega/src/fusion.ml $" }
 
@@ -2367,11 +2367,3 @@ i*)
         constraints = None }
 
   end
-
-(*i
- *  Local Variables:
- *  mode:caml
- *  indent-tabs-mode:nil
- *  page-delimiter:"^(\\* .*\n"
- *  End:
-i*)
