@@ -61,15 +61,15 @@ module Fortran =
       printf "        if (w_wkm.eq.0) then"; nl ();
       printf "          select case (res)"; nl ();
       printf "            case (1) !!! Scalar isosinglet"; nl ();
-      printf "              w = 3*g**2 /128._default/Pi * m**3"; nl ();
+      printf "              w = g**2 /32._default/Pi * m**3"; nl ();
       printf "            case (2) !!! Scalar isoquintet"; nl ();
-      printf "              w = g**2/256._default/Pi * m**3"; nl ();
+      printf "              w = g**2/128._default/Pi * m**3"; nl ();
       printf "            case (3) !!! Vector isotriplet"; nl ();
       printf "              w = g**2/48._default/Pi * m"; nl ();
       printf "            case (4) !!! Tensor isosinglet"; nl ();
-      printf "              w = g**2/1280._default/Pi * m**3"; nl ();
+      printf "              w = g**2/960._default/Pi * m**3"; nl ();
       printf "            case (5) !!! Tensor isoquintet"; nl ();
-      printf "              w = g**2/7680._default/Pi * m**3"; nl ();
+      printf "              w = g**2/3840._default/Pi * m**3"; nl ();
       printf "            case default"; nl ();
       printf "              w = 0"; nl ();
       printf "          end select"; nl ();
@@ -190,7 +190,11 @@ module Fortran =
       printf "                  s**2/cmplx(s-m(1)**2,m(1)*wkm(1),default) "; nl ();
       printf "      end if"; nl ();
       printf "      !!! Scalar isoquintet"; nl ();
-      printf "      a00(2) = -5*cc(2)**2 * s0stu(s,m(2))/12.0_default"; nl ();
+      printf "      a00(2) = -7*cc(2)**2 * s0stu(s,m(2))/8.0_default"; nl ();
+      printf "      if (cc(2) /= 0) then"; nl ();
+      printf "        a00(2) = a00(2) - 1/16.0_default *cc(2)**2 * &"; nl (); 
+      printf "                  s**2/cmplx(s-m(2)**2,m(2)*wkm(2),default) "; nl ();
+      printf "      end if"; nl ();
       printf "      !!! Vector isotriplet"; nl ();
       printf "      a00(3) = -cc(3)**2*(4*p0stu(s,m(3)) + 6*s/m(3)**2)"; nl ();
       printf "      !!! Tensor isosinglet"; nl ();
@@ -202,7 +206,7 @@ module Fortran =
       printf "                   + s0stu(s,m(4))/24.0_default)"; nl ();
       printf "      end if"; nl ();
       printf "      !!! Tensor isoquintet"; nl ();
-      printf "      a00(5) = -5*cc(5)**2 * d0stu(s,m(5))/ 72.0_default "; nl ();
+      printf "      a00(5) = -7*cc(5)**2 * d0stu(s,m(5))/ 48.0_default "; nl ();
       printf "      !!! Transversal"; nl ();
       printf "      !!! Tensor isosinglet"; nl ();
       printf "      a00(6) = - cc(9)**2/Pi/vev**6*mass(23)**2*mass(24)**2* s**2 &"; nl ();
@@ -234,7 +238,7 @@ module Fortran =
       printf "          amp_00 = - a00_a - a00_f - part_r * (sum(a00) - a00(3)) &"; nl ();
       printf "            + 1/(real(1/amp_00,default)-ii)"; nl();
       printf "      !!! Validation !!!"; nl ();
-      printf "      !!!    amp_00 = - a00_a - a00_f - part_r * (sum(a00) - a00(3))"; nl();
+      printf "      !!! amp_00 = - a00_a - a00_f - part_r * (sum(a00) - a00(3))"; nl();
       printf "        end if"; nl ();
       printf "      else"; nl ();
       printf "        amp_00 = (1-part_r) * sum(a00) + part_r * a00(3)"; nl ();
@@ -264,7 +268,7 @@ module Fortran =
       printf "      !!! Scalar  isosinglet"; nl ();
       printf "      a02(1) = -cc(1)**2/2.0_default * s2stu(s,m(1))"; nl ();
       printf "      !!! Scalar isoquintet"; nl ();
-      printf "      a02(2) = -5*cc(2)**2 * s2stu(s,m(2)) / 12.0_default"; nl ();
+      printf "      a02(2) = -7*cc(2)**2 * s2stu(s,m(2)) / 8.0_default"; nl ();
       printf "      !!! Vector isotriplet"; nl (); 
       printf "      a02(3) = -4*cc(3)**2*(2*s+m(3)**2)*s2stu(s,m(3))/m(3)**4"; nl ();
       printf "      !!! Tensor isosinglet"; nl (); 
@@ -279,8 +283,12 @@ module Fortran =
       printf "                 cc(13) * s2stu(s,m(4))/24.0_default"; nl ();
       printf "      end if"; nl ();
       printf "      !!! Tensor isoquintet"; nl ();
-      printf "      a02(5) = -cc(5)**2 * 5.0_default / 72.0_default *(1._default+6* &"; nl ();
+      printf "      a02(5) = -cc(5)**2 * 7.0_default / 48.0_default *(1._default+6* &"; nl ();
       printf "               s/m(5)**2+6*s**2/m(5)**4)*s2stu(s,m(5)) "; nl (); 
+      printf "      if (cc(5) /= 0) then"; nl ();
+      printf "        a02(5) = a02(5) - cc(5)**2/480.0_default &"; nl (); 
+      printf "                  * s**2/cmplx(s-m(5)**2,m(5)*wkm(5),default)"; nl ();
+      printf "      end if"; nl ();
       printf "      !!! Transversal"; nl ();
       printf "      !!! Tensor isosinglet"; nl ();
       printf "      a02(6) = - cc(9)**2/Pi/vev**6*mass(23)**2*mass(24)**2 * s**2/40"; nl ();
@@ -338,7 +346,7 @@ module Fortran =
       printf "      !!! Scalar isosinglet"; nl ();
       printf "      a11(1) = - cc(1)**2/2.0_default * s1stu(s,m(1))"; nl ();
       printf "      !!! Scalar isoquintet"; nl ();
-      printf "      a11(2) = 5*cc(2)**2 * s1stu(s,m(2)) / 24.0_default"; nl ();
+      printf "      a11(2) = 3*cc(2)**2 * s1stu(s,m(2)) / 8.0_default"; nl ();
       printf "      !!! Vector isotriplet"; nl ();
       printf "      a11(3) = - cc(3)**2 * &"; nl ();
       printf "                 (s/m(3)**2 + 2 * p1stu(s,m(3)))"; nl ();
@@ -354,7 +362,7 @@ module Fortran =
       printf "                 cc(13) * s1stu(s,m(4))/24.0_default "; nl ();
       printf "      end if"; nl ();
       printf "      !!! Tensor isoquintet"; nl ();
-      printf "      a11(5) =  cc(5)**2 * 5.0_default / 144.0_default * d1stu(s,m(5)) "; nl ();
+      printf "      a11(5) =  cc(5)**2 / 16.0_default * d1stu(s,m(5)) "; nl ();
       printf "      !!! Transversal"; nl ();
       printf "      !!! Tensor isosinglet"; nl ();
       printf "      a11(6) = -cc(9)**2/Pi/vev**6*mass(23)**2*mass(24)**2/12._default * (s1stu(s,m(4)) * &"; nl ();
@@ -406,9 +414,9 @@ module Fortran =
       printf "      !!! Longitudinal"; nl ();
       printf "      a20(1) = -cc(1)**2/2.0_default * s0stu(s,m(1))"; nl ();
       printf "      !!! Scalar isoquintet"; nl ();
-      printf "      a20(2) = - cc(2)**2 * s0stu(s,m(2)) /24.0_default"; nl ();
+      printf "      a20(2) = - cc(2)**2 * s0stu(s,m(2)) /8.0_default"; nl ();
       printf "      if (cc(2) /= 0) then"; nl ();
-      printf "        a20(2) = a20(2) - cc(2)**2 /8.0_default *&"; nl (); 
+      printf "        a20(2) = a20(2) - cc(2)**2 /4.0_default *&"; nl (); 
       printf "                 s**2/cmplx(s-m(2)**2,m(2)*wkm(2),default)"; nl ();
       printf "      end if"; nl ();
       printf "      !!! Vector isotriplet"; nl ();
@@ -421,7 +429,7 @@ module Fortran =
       printf "                 cc(13) * s0stu(s,m(4))/24.0_default "; nl ();
       printf "      end if"; nl ();
       printf "      !!! Tensor isoquintet"; nl ();
-      printf "      a20(5) = - cc(5)**2/ 144.0_default * d0stu(s,m(5)) "; nl ();
+      printf "      a20(5) = - cc(5)**2/ 48.0_default * d0stu(s,m(5)) "; nl ();
       printf "      !!! Transversal"; nl ();
       printf "      !!! Tensor isosinglet"; nl ();
       printf "      a20(6) = -cc(9)**2/Pi/vev**6*mass(23)**2*mass(24)**2/12._default * (s0stu(s,m(4)) &"; nl ();
@@ -475,7 +483,7 @@ module Fortran =
       printf "      !!! Scalar isosinglet"; nl ();
       printf "      a22(1) = - cc(1)**2/2.0_default * s2stu(s,m(1))"; nl ();
       printf "      !!! Scalar isoquintet"; nl ();
-      printf "      a22(2) = - cc(2)**2 * s2stu(s,m(2))/ 24.0_default"; nl ();
+      printf "      a22(2) = - cc(2)**2 * s2stu(s,m(2))/ 8.0_default"; nl ();
       printf "      !!! Vector triplet"; nl ();
       printf "      a22(3) = 2*cc(3)**2*(2*s+m(3)**2)*s2stu(s,m(3))/m(3)**4"; nl ();
       printf "      !!! Tensor isosinglet"; nl ();
@@ -486,11 +494,11 @@ module Fortran =
       printf "                  cc(13) * s2stu(s,m(4)) / 24.0_default "; nl ();
       printf "      end if"; nl ();
       printf "      !!! Tensor isoquintet"; nl ();
-      printf "      a22(5) = - cc(5)**2/144._default * &"; nl ();
+      printf "      a22(5) = - cc(5)**2/48._default * &"; nl ();
       printf "                 ((1._default+6*s/m(5)**2+6*s**2/m(5)**4 ) &"; nl (); 
       printf "                 * s2stu(s,m(5)))"; nl ();
       printf "      if (cc(5) /= 0) then"; nl ();
-      printf "        a22(5) = a22(5) - cc(5)**2/240._default * &"; nl (); 
+      printf "        a22(5) = a22(5) - cc(5)**2/120._default * &"; nl (); 
       printf "               s**2/cmplx(s-m(5)**2,m(5)*wkm(5),default)"; nl ();
       printf "      end if"; nl ();
       printf "      !!! Transversal"; nl ();
