@@ -1,4 +1,4 @@
-! WHIZARD 2.2.7 Aug 11 2015
+! WHIZARD 2.2.8 Nov 22 2015
 ! 
 ! Copyright (C) 1999-2015 by 
 !     Wolfgang Kilian <kilian@physik.uni-siegen.de>
@@ -6,11 +6,14 @@
 !     Juergen Reuter <juergen.reuter@desy.de>
 !     
 !     with contributions from
-!     Fabian Bach <fabian.bach@desy.de>
+!     Fabian Bach <fabian.bach@t-online.de>
+!     Bijan Chokoufe <bijan.chokoufe@desy.de>
 !     Christian Speckner <cnspeckn@googlemail.com> 
+!     Soyoung Shim <soyoung.shim@desy.de>
+!     Florian Staub <florian.staub@cern.ch>  
 !     Christian Weiss <christian.weiss@desy.de>
 !     and Hans-Werner Boschmann, Felix Braam, 
-!     Sebastian Schmidt, Daniel Wiesler 
+!     Sebastian Schmidt, So-young Shim, Daniel Wiesler 
 !
 ! WHIZARD is free software; you can redistribute it and/or modify it
 ! under the terms of the GNU General Public License as published by 
@@ -603,12 +606,12 @@ contains
     write (u, "(A)")
     write (u, "(A)")  "* Structure function #1"
     write (u, "(A)")
-    call sf_int(1)%write (u)
+    call sf_int(1)%write (u, testflag = .true.)
     
     write (u, "(A)")
     write (u, "(A)")  "* Structure function #2"
     write (u, "(A)")
-    call sf_int(2)%write (u)
+    call sf_int(2)%write (u, testflag = .true.)
     
     write (u, "(A)")
     write (u, "(A)")  "* Structure-function value, default order"
