@@ -1,4 +1,4 @@
-! WHIZARD 2.2.7 Aug 11 2015
+! WHIZARD 2.2.8 Nov 22 2015
 ! 
 ! Copyright (C) 1999-2015 by 
 !     Wolfgang Kilian <kilian@physik.uni-siegen.de>
@@ -6,11 +6,14 @@
 !     Juergen Reuter <juergen.reuter@desy.de>
 !     
 !     with contributions from
-!     Fabian Bach <fabian.bach@desy.de>
+!     Fabian Bach <fabian.bach@t-online.de>
+!     Bijan Chokoufe <bijan.chokoufe@desy.de>
 !     Christian Speckner <cnspeckn@googlemail.com> 
+!     Soyoung Shim <soyoung.shim@desy.de>
+!     Florian Staub <florian.staub@cern.ch>  
 !     Christian Weiss <christian.weiss@desy.de>
 !     and Hans-Werner Boschmann, Felix Braam, 
-!     Sebastian Schmidt, Daniel Wiesler 
+!     Sebastian Schmidt, So-young Shim, Daniel Wiesler 
 !
 ! WHIZARD is free software; you can redistribute it and/or modify it
 ! under the terms of the GNU General Public License as published by 
@@ -63,7 +66,7 @@ module real_subtraction
   type :: soft_subtraction_t
     real(default), dimension(:), allocatable :: value
     type(region_data_t) :: reg_data
-    integer :: nlegs_born, nlegs_real
+    integer :: n_in, nlegs_born, nlegs_real
     real(default), dimension(:,:), allocatable :: momentum_matrix
     logical :: use_internal_color_correlations = .true.
     logical :: use_internal_spin_correlations = .false.
@@ -79,7 +82,7 @@ module real_subtraction
   type :: coll_subtraction_t
     real(default), dimension(:), allocatable :: value
     real(default), dimension(:), allocatable :: value_soft
-    integer :: n_alr
+    integer :: n_in, n_alr
     real(default), dimension(0:3,0:3) :: b_munu
     type(pdf_container_t), pointer :: pdf_born_plus => null ()
     type(pdf_container_t), pointer :: pdf_born_minus => null ()
@@ -135,12 +138,13 @@ module real_subtraction
 
 contains
 
-  subroutine soft_subtraction_init (sub_soft, reg_data, nlegs_born, &
-                                    nlegs_real)
+  subroutine soft_subtraction_init (sub_soft, reg_data, &
+      n_in, nlegs_born, nlegs_real)
     class(soft_subtraction_t), intent(inout) :: sub_soft
     type(region_data_t), intent(in) :: reg_data
-    integer, intent(in) :: nlegs_born, nlegs_real
+    integer, intent(in) :: n_in, nlegs_born, nlegs_real
     sub_soft%reg_data = reg_data
+    sub_soft%n_in = n_in
     sub_soft%nlegs_born = nlegs_born
     sub_soft%nlegs_real = nlegs_real
     allocate (sub_soft%value (reg_data%n_regions))
@@ -155,16 +159,16 @@ contains
     type(vector4_t) :: p_soft
     type(vector3_t) :: dir
     type(lorentz_transformation_t) :: rot
-    p_soft%p(0) = 1._default
+    p_soft%p(0) = one
     p_soft%p(1:3) = p_born(emitter)%p(1:3) / space_part_norm (p_born(emitter))
     dir = create_orthogonal (space_part (p_born(emitter)))
-    rot = rotation (y, sqrt(1-y**2), dir)
-    p_soft = rot*p_soft
+    rot = rotation (y, sqrt(one - y**2), dir)
+    p_soft = rot * p_soft
     if (.not. vanishes (phi)) then
       dir = space_part (p_born(emitter)) / &
             space_part_norm (p_born(emitter))
       rot = rotation (cos(phi), sin(phi), dir)
-      p_soft = rot*p_soft
+      p_soft = rot * p_soft
     end if
   end function create_softvec_fsr
 
@@ -172,8 +176,8 @@ contains
     real(default), intent(in) :: y, phi
     type(vector4_t) :: p_soft
     real(default) :: sin_theta
-    sin_theta = sqrt(1-y**2)
-    p_soft%p(0) = 1._default
+    sin_theta = sqrt(one - y**2)
+    p_soft%p(0) = one
     p_soft%p(1) = sin_theta * sin(phi)
     p_soft%p(2) = sin_theta * cos(phi)
     p_soft%p(3) = y
@@ -199,7 +203,7 @@ contains
        call msg_fatal ("Soft subtraction: phase space point must be in CMS")
     end if
 
-    if (emitter > 2) then
+    if (emitter > sub_soft%n_in) then
        p_soft = create_softvec_fsr (p_born, y_soft, phi, emitter)
     else
        p_soft = create_softvec_isr (y_soft, phi)
@@ -207,19 +211,28 @@ contains
     s_alpha_soft = sub_soft%reg_data%get_svalue_soft &
          (p_born, p_soft, alr, emitter)
     call sub_soft%compute_momentum_matrix (p_born, p_soft)
-    sub_soft%value(alr) = 4*pi*alpha_s_born * s_alpha_soft
-    kb = 0._default
+    sub_soft%value(alr) = 4*pi * alpha_s_born * s_alpha_soft
+    kb = zero
     do i = 1, size (p_born)
        do j = 1, size (p_born)
           kb = kb + sub_soft%momentum_matrix (i,j) * &
-               born_ij (i,j)
+             born_ij (i,j)
        end do
     end do
     if (debug_active (D_SUBTRACTION)) &
        call msg_debug (D_SUBTRACTION, 'KB', kb)
     sub_soft%value(alr) = sub_soft%value(alr)*kb
-    q2 = 4 * p_born(1)%p(0)*p_born(2)%p(0)
-    sub_soft%value(alr) = 4/q2 * (1-y) * sub_soft%value(alr)
+    select case (sub_soft%n_in)
+    case (1) 
+       q2 = p_born(1)%p(0)**2
+    case (2)
+       q2 = 4 * p_born(1)%p(0) * p_born(2)%p(0)
+    end select
+    if (emitter <= sub_soft%n_in) then
+       sub_soft%value(alr) = 4/q2 * (one-y**2) * sub_soft%value(alr)
+    else
+       sub_soft%value(alr) = 4/q2 * (one-y) * sub_soft%value(alr)
+    end if
   end subroutine soft_subtraction_compute
 
   subroutine soft_subtraction_compute_momentum_matrix &
@@ -233,9 +246,9 @@ contains
       do j = 1, sub_soft%nlegs_born
         if (i <= j) then
           num = p_born(i) * p_born(j)
-          deno1 = p_born(i)*p_soft
-          deno2 = p_born(j)*p_soft
-          sub_soft%momentum_matrix(i,j) = num/(deno1*deno2)
+          deno1 = p_born(i) * p_soft
+          deno2 = p_born(j) * p_soft
+          sub_soft%momentum_matrix(i,j) = num / (deno1 * deno2)
         else
            !!! momentum matrix is symmetric.
           sub_soft%momentum_matrix(i,j) = sub_soft%momentum_matrix(j,i)
@@ -244,9 +257,10 @@ contains
     end do
   end subroutine soft_subtraction_compute_momentum_matrix
 
-  subroutine coll_subtraction_init (coll_sub, n_alr)
+  subroutine coll_subtraction_init (coll_sub, n_alr, n_in)
     class(coll_subtraction_t), intent(inout) :: coll_sub
-    integer, intent(in) :: n_alr
+    integer, intent(in) :: n_alr, n_in
+    coll_sub%n_in = n_in
     coll_sub%n_alr = n_alr
     allocate (coll_sub%value (n_alr))
     allocate (coll_sub%value_soft (n_alr))
@@ -273,7 +287,7 @@ contains
 
     if (.not. vector_set_is_cms (p_born)) then
        call vector4_write_set (p_born, show_mass = .true., &
-          check_conservation = .true.)
+          check_conservation = .true., n_in = coll_sub%n_in)
        call msg_fatal ("Collinear subtraction, FSR: Phase space point &
           &must be in CMS")
     end if
@@ -288,27 +302,32 @@ contains
     flv_rad = sregion%flst_real%flst(nlegs)
     flv_em = sregion%flst_real%flst(emitter)
     p0 = p_born(emitter)%p(0)
-    q0 = p_born(1)%p(0) + p_born(2)%p(0)
+    select case (coll_sub%n_in)
+    case (1)
+       q0 = p_born(1)%p(0)
+    case (2)
+       q0 = p_born(1)%p(0) + p_born(2)%p(0)
+    end select
     !!! Here, z corresponds to 1-z in the formulas of arXiv:1002.2581;
     !!! the integrand is symmetric under this variable change
-    zoxi = q0/(2*p0)
-    z = xi*zoxi; onemz = 1-z
+    zoxi = q0 / (two * p0)
+    z = xi * zoxi; onemz = one - z 
 
     if (is_gluon(flv_em) .and. is_gluon(flv_rad)) then
-       pggz = 2*CA*(z**2*onemz + z**2/onemz + onemz)
-       res = pggz*sqme_born - 4*CA*z**2*onemz*sqme_born_sc
-       res = res/zoxi
+       pggz = two * CA * (z**2 * onemz + z**2 / onemz + onemz)
+       res = pggz * sqme_born - 4 * CA * z**2 * onemz * sqme_born_sc
+       res = res / zoxi
     else if (is_quark(abs(flv_em)) .and. is_quark (abs(flv_rad))) then
-       pqgz = TR*z*(1-2*z*onemz)
-       res = pqgz*sqme_born + 4*TR*z**2*onemz*sqme_born_sc
-       res = res/zoxi
+       pqgz = TR * z * (one - two * z * onemz)
+       res = pqgz * sqme_born + 4 * TR * z**2 * onemz * sqme_born_sc
+       res = res / zoxi
     else if (is_quark (abs(flv_em)) .and. is_gluon (flv_rad)) then
-       res = sqme_born*CF*(1+onemz**2)/zoxi
+       res = sqme_born * CF * (one + onemz**2) / zoxi
     else
        call msg_fatal ('Impossible flavor structure in collinear counterterm!')
     end if
-    res = res /(p0**2*onemz*zoxi)
-    res = res * 4*pi*alpha_s
+    res = res / (p0**2 * onemz * zoxi)
+    res = res * 4*pi * alpha_s
 
     if (soft) then
       coll_sub%value_soft (alr) = res
@@ -365,14 +384,15 @@ contains
     nlegs = size (sregion%flst_real%flst)
     flv_rad = sregion%flst_real%flst(nlegs)
     flv_em = sregion%flst_real%flst(isr_mode)
-    !!!p02 = p_born(isr_mode)%p(0)**2
-    p02 = p_born(1)%p(0)*p_born(2)%p(0)/2
-    z = one-xi; onemz = xi
+    !!! No need to pay attention to n_in = 1, because this case always has a
+    !!! massive initial-state particle and thus no collinear divergence.
+    p02 = p_born(1)%p(0) * p_born(2)%p(0) / two
+    z = one - xi; onemz = xi
 
     if (is_quark(abs(flv_em)) .and. is_gluon(flv_rad)) then
-       res = CF*(1+z**2)*sqme_born
+       res = CF * (one + z**2) * sqme_born
     else if (is_gluon(flv_em) .and. is_quark (abs(flv_rad))) then
-       res = TR*(z**2+onemz**2)*onemz*sqme_born
+       res = TR* (z**2 + onemz**2) * onemz * sqme_born
     end if
     res = res * z/p02
     res = res * 4*pi*alpha_s
@@ -397,11 +417,11 @@ contains
        zero, alpha_s, alr, isr_mode, .true. )
   end subroutine coll_subtraction_compute_soft_limit_isr
 
-  subroutine real_subtraction_init (rsub, reg_data, nlegs_born, &
-                                    nlegs_real, sqme_collector)
+  subroutine real_subtraction_init (rsub, reg_data, n_in, &
+      nlegs_born, nlegs_real, sqme_collector)
     class(real_subtraction_t), intent(inout), target :: rsub
     type(region_data_t), intent(in) :: reg_data
-    integer, intent(in) :: nlegs_born, nlegs_real
+    integer, intent(in) :: n_in, nlegs_born, nlegs_real
     type(sqme_collector_t), intent(in), target :: sqme_collector
     integer :: alr, i_uborn
     rsub%reg_data = reg_data
@@ -416,10 +436,10 @@ contains
           reg_data%flv_born(i_uborn)%count_particle (GLUON) > 0
     end do
 
-    call rsub%sub_soft%init (reg_data, nlegs_born, nlegs_real)
-    call rsub%sub_coll%init (reg_data%n_regions)
+    call rsub%sub_soft%init (reg_data, n_in, nlegs_born, nlegs_real)
+    call rsub%sub_coll%init (reg_data%n_regions, n_in)
 
-    if (any (rsub%reg_data%get_emitter_list () <= 2)) then
+    if (rsub%reg_data%n_in > 1 .and. any (rsub%reg_data%get_emitter_list () <= 2)) then
        call rsub%init_pdfs ()
        rsub%sub_soft%pdf_born_plus => rsub%pdf_born(I_PLUS)
        rsub%sub_soft%pdf_born_minus => rsub%pdf_born(I_MINUS)
@@ -477,12 +497,12 @@ contains
     real(default) :: sqme
     integer :: alr
 
-    sqme = 0._default
+    sqme = zero
     do alr = 1, size (rsub%reg_data%regions)
         if (emitter == rsub%reg_data%regions(alr)%emitter .and. &
             i_flv == rsub%reg_data%regions(alr)%real_index) then
             call rsub%set_alr (alr)
-            if (emitter <= 2) then
+            if (emitter <= rsub%isr_kinematics%n_in) then
                sqme = sqme + rsub%evaluate_region_isr (emitter, alpha_s)
             else
                sqme = sqme + rsub%evaluate_region_fsr (emitter, alpha_s)
@@ -490,7 +510,7 @@ contains
         end if
     end do
     if (rsub%purpose == INTEGRATION .or. rsub%purpose == FIXED_ORDER_EVENTS) &
-        sqme = sqme*rsub%get_phs_factor ()
+        sqme = sqme * rsub%get_phs_factor ()
   end function real_subtraction_compute
 
   function real_subtraction_evaluate_region_fsr (rsub, emitter, &
@@ -531,15 +551,15 @@ contains
       if (rsub%subtraction_active) then
          call rsub%evaluate_subtraction_terms_fsr (emitter, alpha_s, &
                    sqme_soft, sqme_coll, sqme_cs)
-         sqme_soft = sqme_soft/onemy/xi_tilde
-         sqme_coll = sqme_coll/onemy/xi_tilde
-         sqme_cs = sqme_cs/onemy/xi_tilde
+         sqme_soft = sqme_soft / onemy / xi_tilde
+         sqme_coll = sqme_coll / onemy / xi_tilde
+         sqme_cs = sqme_cs / onemy / xi_tilde
          associate (jac => rsub%real_kinematics%jac)
             sqme_soft = sqme_soft * jac(emitter)%jac(2)
             sqme_coll = sqme_coll * jac(emitter)%jac(3)
             sqme_cs = sqme_cs * jac(emitter)%jac(2)
          end associate
-         sqme_remn = (sqme_soft - sqme_cs)*log(xi_max)*xi_tilde
+         sqme_remn = (sqme_soft - sqme_cs) * log(xi_max) * xi_tilde
          select case (rsub%purpose)
          case (INTEGRATION)
             sqme = sqme0 - sqme_soft - sqme_coll + sqme_cs + sqme_remn
@@ -593,19 +613,29 @@ contains
     real(default) :: sqme_remn
     real(default) :: s_alpha
     real(default) :: onemy, onepy
+    logical :: proc_scatter
+
+    proc_scatter = rsub%isr_kinematics%n_in == 2
 
     xi_tilde = rsub%real_kinematics%xi_tilde
     xi_max = rsub%real_kinematics%xi_max(1)
-    xi_max_plus = one - rsub%isr_kinematics%x(I_PLUS)
-    xi_max_minus = one - rsub%isr_kinematics%x(I_MINUS)
     xi = xi_tilde * xi_max
-    xi_plus = xi_max_plus * xi_tilde
-    xi_minus = xi_max_minus * xi_tilde
+    if (proc_scatter) then 
+       xi_max_plus = one - rsub%isr_kinematics%x(I_PLUS)
+       xi_max_minus = one - rsub%isr_kinematics%x(I_MINUS)
+       xi_plus = xi_max_plus * xi_tilde
+       xi_minus = xi_max_minus * xi_tilde
+    else 
+       xi_max_plus = xi_max
+       xi_max_minus = xi_max
+       xi_plus =  xi
+       xi_minus = xi
+    end if
     y = rsub%real_kinematics%y(1)
-    onemy = one-y; onepy = one+y
+    onemy = one - y; onepy = one + y
     phi = rsub%real_kinematics%phi
 
-    call rsub%compute_pdfs ()
+    if (proc_scatter) call rsub%compute_pdfs ()
 
     associate (region => rsub%reg_data%regions(rsub%current_alr))
       i_real = region%real_index
@@ -613,42 +643,44 @@ contains
       s_alpha = rsub%reg_data%get_svalue (rsub%real_kinematics%p_real_cms, rsub%current_alr, emitter)
       sqme0 = sqme0 * s_alpha
       sqme0 = sqme0 * region%mult
-      call rsub%reweight_pdfs (sqme0, i_real, I_PLUS)
-      call rsub%reweight_pdfs (sqme0, i_real, I_MINUS)
-
-      if (rsub%subtraction_active) then
-         sqme0 = sqme0 * xi**2/xi_tilde * rsub%real_kinematics%jac(1)%jac(1)
-      else
-         !!! What is the proper jacobian-prefactor ?
+      if (proc_scatter) then
+         call rsub%reweight_pdfs (sqme0, i_real, I_PLUS)
+         call rsub%reweight_pdfs (sqme0, i_real, I_MINUS)
       end if
+
+      select case (rsub%purpose)
+      case (INTEGRATION, FIXED_ORDER_EVENTS)
+         sqme0 = sqme0 * xi**2/xi_tilde * rsub%real_kinematics%jac(emitter)%jac(1)
+      case (POWHEG)
+         call msg_fatal ("POWHEG with initial-state radiation not implemented yet")
+      end select
+
       if (rsub%subtraction_active) then
          call rsub%evaluate_subtraction_terms_isr (emitter, alpha_s, &
             sqme_soft, sqme_coll_plus, sqme_coll_minus, sqme_cs_plus, sqme_cs_minus)
-         call rsub%reweight_pdfs (sqme_coll_plus, i_real, I_PLUS)
-         call rsub%reweight_pdfs (sqme_coll_minus, i_real, I_MINUS)
-         !!!call rsub%reweight_pdfs (sqme_cs_plus, I_PLUS)
-         !!!call rsub%reweight_pdfs (sqme_cs_minus, I_MINUS)
+         if (proc_scatter) then
+            call rsub%reweight_pdfs (sqme_coll_plus, i_real, I_PLUS)
+            call rsub%reweight_pdfs (sqme_coll_minus, i_real, I_MINUS)
+         end if
          associate (jac => rsub%real_kinematics%jac)
-           sqme_soft = sqme_soft/(one-y**2)/xi_tilde * jac(1)%jac(2)
-           sqme_coll_plus = sqme_coll_plus/onemy/xi_tilde/two * jac(1)%jac(3)
-           sqme_coll_minus = sqme_coll_minus/onepy/xi_tilde/two * jac(1)%jac(4)
-           sqme_cs_plus = sqme_cs_plus/onemy/xi_tilde/two * jac(1)%jac(2)
-           sqme_cs_minus = sqme_cs_minus/onepy/xi_tilde/two * jac(1)%jac(2)
+           sqme_soft = sqme_soft / (one - y**2) / xi_tilde * jac(1)%jac(2)
+           sqme_coll_plus = sqme_coll_plus / onemy / xi_tilde / two * jac(1)%jac(3)
+           sqme_coll_minus = sqme_coll_minus / onepy / xi_tilde / two * jac(1)%jac(4)
+           sqme_cs_plus = sqme_cs_plus / onemy / xi_tilde / two * jac(1)%jac(2)
+           sqme_cs_minus = sqme_cs_minus / onepy / xi_tilde / two * jac(1)%jac(2)
          end associate
-         !!!sqme_remn = log(xi_max_plus)/onemy * (sqme_soft - sqme_coll_plus) &
-         !!!          + log(xi_max_minus)/onepy * (sqme_soft - sqme_coll_minus)
-         !!!sqme_remn = sqme_remn * xi_tilde/2
          sqme_remn = log(xi_max) * xi_tilde * sqme_soft
-         sqme_remn = sqme_remn - log(xi_max_plus)*xi_tilde*sqme_cs_plus &
-                               - log(xi_max_minus)*xi_tilde*sqme_cs_minus
+         sqme_remn = sqme_remn - log (xi_max_plus) * xi_tilde * sqme_cs_plus &
+                               - log (xi_max_minus) * xi_tilde * sqme_cs_minus
 
          sqme = sqme0 - sqme_soft - sqme_coll_plus - sqme_coll_minus &
               + sqme_cs_plus + sqme_cs_minus + sqme_remn
-         sqme = sqme*rsub%real_kinematics%jac_rand (1)
       else
          sqme = sqme0
       end if
     end associate
+         
+    sqme = sqme * rsub%real_kinematics%jac_rand (1)
 
     if (debug_active (D_SUBTRACTION)) then
        call msg_debug (D_SUBTRACTION, "real_subtraction_evaluate_region_isr")
@@ -665,7 +697,6 @@ contains
        write (u,'(A,I2)') 'alr: ', rsub%current_alr
        write (u,'(A,I2)') 'emitter: ', emitter
        write (u,'(A,F4.2)') 'xi_max: ', xi_max
-       !!!write (u,'(A,F4.2,A,F4.2)') 'xi: ', xi, 'y: ', y
        print *, 'xi: ', xi, 'y: ', y
        print *, 'phi: ', phi
        print *, 'xb1: ', rsub%isr_kinematics%x(1), 'xb2: ', rsub%isr_kinematics%x(2)
@@ -739,7 +770,12 @@ contains
     real(default) :: s
     associate (real_kin => rsub%real_kinematics)
        !!! Lorentz invariant, does not matter whether cm or lab frame is used
-       s = (real_kin%p_born_cms(1)+real_kin%p_born_cms(2))**2
+       select case (rsub%isr_kinematics%n_in)
+       case (1) 
+          s = real_kin%p_born_cms(1)**2
+       case (2) 
+          s = (real_kin%p_born_cms(1) + real_kin%p_born_cms(2))**2
+       end select
     end associate
     factor = s / (8*twopi3)
   end function real_subtraction_get_phs_factor
@@ -764,7 +800,7 @@ contains
                                       rsub%real_kinematics%phi, &
                                       alpha_s, alr, emitter)
        else
-          rsub%sub_soft%value(alr) = 0._default
+          rsub%sub_soft%value(alr) = zero
        end if
     end associate
   end subroutine real_subtraction_compute_sub_soft
@@ -796,8 +832,8 @@ contains
     xi = rsub%real_kinematics%xi_tilde * rsub%real_kinematics%xi_max (em)
     associate (sregion => rsub%reg_data%regions(alr))
        if (sregion%has_collinear_divergence ()) then
-           sqme_sc = rsub%get_sc_matrix_element (alr, em, sregion%uborn_index)
-          if (em <= 2) then
+          sqme_sc = rsub%get_sc_matrix_element (alr, em, sregion%uborn_index)
+          if (em <= rsub%sub_coll%n_in) then
              call rsub%sub_coll%compute_isr (sregion, rsub%real_kinematics%p_born_lab, &
                 rsub%sqme_born(sregion%uborn_index), sqme_sc, xi, alpha_s, alr, em)
           else
@@ -805,7 +841,7 @@ contains
                 rsub%sqme_born(sregion%uborn_index), sqme_sc, xi, alpha_s, alr)
           end if
        else
-          rsub%sub_coll%value(alr) = 0._default
+          rsub%sub_coll%value(alr) = zero
        end if
     end associate
   end subroutine real_subtraction_compute_sub_coll
@@ -822,7 +858,7 @@ contains
     associate (sregion => rsub%reg_data%regions(alr))
        if (sregion%has_collinear_divergence ()) then
           sqme_sc = rsub%get_sc_matrix_element (alr, em, sregion%uborn_index)
-          if (em <= 2) then
+          if (em <= rsub%sub_coll%n_in) then
              call rsub%sub_coll%compute_soft_limit_isr (sregion, rsub%real_kinematics%p_born_lab, &
                 rsub%sqme_born(sregion%uborn_index), sqme_sc, xi, alpha_s, alr, em)
           else
@@ -830,7 +866,7 @@ contains
                 rsub%sqme_born(sregion%uborn_index), sqme_sc, xi, alpha_s, alr)
           end if
        else
-          rsub%sub_coll%value_soft(alr) = 0._default
+          rsub%sub_coll%value_soft(alr) = zero
        end if
     end associate
   end subroutine real_subtraction_compute_sub_coll_soft
@@ -845,7 +881,7 @@ contains
     do i = 1, 2
        x = rsub%isr_kinematics%x(i)
        z = rsub%isr_kinematics%z(i)
-       x_scaled = x/z
+       x_scaled = x / z
        call rsub%pdf_data%evolve (dble(x), dble(Q), f_dble)
        rsub%pdf_born(i)%f = f_dble / dble(x)
        call rsub%pdf_data%evolve (dble(x_scaled), dble(Q), f_dble)
