@@ -6,7 +6,7 @@
 !     Juergen Reuter <juergen.reuter@desy.de>
 !     with contributions from
 !     Christian Speckner <cnspeckn@googlemail.com>
-!     Marco Sekulla <sekulla@physik.uni-siegen.de> (only this file)
+!     Marco Sekulla <marco.sekulla@kit.edu> (only this file)
 !
 ! WHIZARD is free software; you can redistribute it and/or modify it
 ! under the terms of the GNU General Public License as published by 
@@ -29,7 +29,7 @@ module parameters_alth
   implicit none
   private
 
-  real(default), dimension(55), public :: mass, width
+  real(default), dimension(59), public :: mass, width
   real(default), public :: as
   complex(default), public :: gs, igs
 
@@ -41,8 +41,10 @@ module parameters_alth
        iqw, igzww, igwww, gw4, gzzww, gazww, gaaww, &
        gszz, gszzt, gsww, gswwt, gssww, gsszz, &
        gpnww, gpnzz, gpwz, gpww, &
+       gpsnww, gpsnzz, gpsnhh, &
        gfww, gfzz, gfwwt, gfzzt, &
-       gtnww, gtnzz, gtwz, gtww
+       gtnww, gtnzz, gtwz, gtww, &
+       gtsnww, gtsnzz
   real(default), public :: vev
   complex(default), dimension(2), public :: &
        gncneu, gnclep, gncup, gncdwn
@@ -229,6 +231,8 @@ contains
     width(47) = par%wkm_p
     mass(48) = par%mkm_p
     width(48) = par%wkm_p
+    mass(49) = par%mkm_p
+    width(49) = par%wkm_p
     mass(52) = par%mkm_f
     width(52) = par%wkm_f
     mass(53) = par%mkm_t
@@ -237,6 +241,8 @@ contains
     width(54) = par%wkm_t
     mass(55) = par%mkm_t
     width(55) = par%wkm_t
+    mass(59) = par%mkm_t
+    width(59) = par%wkm_t
     mkm(1) = par%mkm_s
     mkm(2) = par%mkm_p
     mkm(3) = par%mkm_r
@@ -326,6 +332,9 @@ contains
     gszzt = gkm(6) * g**3 / costhw**3 / mass(23) /(16.0 * PI)
     gpnww = - gkm(2) * mass(24) * g / 2 / sqrt(3.0_default)
     gpnzz = gkm(2) * mass(23) * g / costhw  / sqrt(3.0_default)
+    gpsnww = 0
+    gpsnzz = 0
+    gpsnhh = 0
     gpwz = gkm(2) * mass(23) * g / 2
     gpww = gkm(2) * mass(24) * g / sqrt(2.0_default)
     gfww = gkm(4) * mass(24) * g / 2
@@ -334,6 +343,8 @@ contains
     gfzzt = gkm(9) * g**3 / costhw**3 / mass(23) /(32.0 * PI)
     gtnww = - gkm(5) * mass(24) * g / 4 / sqrt(3.0_default)
     gtnzz = gkm(5) * mass(23) * g / costhw / 2 / sqrt(3.0_default)
+    gtsnww = 0
+    gtsnzz = 0
     gtwz = gkm(5) * mass(23) * g / 4
     gtww = gkm(5) * mass(24) * g / 2 / sqrt(2.0_default)
     gssww = 0
