@@ -29,7 +29,7 @@ module parameters_ssc_altt
   implicit none
   private
 
-  real(default), dimension(58), public :: mass, width
+  real(default), dimension(59), public :: mass, width
   real(default), public :: as
   complex(default), public :: gs, igs
 
@@ -43,10 +43,12 @@ module parameters_ssc_altt
        iqw, igzww, igwww, gw4, gzzww, gazww, gaaww, &
        gszz, gszzt, gsww, gswwt, gssww, gsszz, &
        gpnww, gpnzz, gpwz, gpww, &
+       gpsnww, gpsnzz, gpsnhh, &
        gfww, gfzz, gfwwt, gfzzt, &
        gcf, gfwwcf, gfzzcf, &
        gtnww, gtnzz, gtwz, gtww, &
        gtnwwcf, gtnzzcf, gtwzcf, gtwwcf, &
+       gtsnww, gtsnzz, gtsnwwcf, gtsnzzcf, &
        fs0hhww, fs0hhzz, fs1hhww, fs1hhzz, fsh4, &
        gshh, gfhh, gfhhcf, &
        gffww, gffzz, gffwwcf, gffzzcf, gffhh, gffhhcf, &
@@ -258,6 +260,8 @@ contains
     width(47) = par%wkm_p
     mass(48) = par%mkm_p
     width(48) = par%wkm_p
+    mass(49) = par%mkm_p
+    width(49) = par%wkm_p
     mass(52) = par%mkm_f
     width(52) = par%wkm_f
     mass(53) = par%mkm_t
@@ -272,6 +276,8 @@ contains
     width(57) = par%wkm_f
     mass(58) = par%mkm_f
     width(58) = par%wkm_f
+    mass(59) = par%mkm_t
+    width(59) = par%wkm_t
     mkm(1) = par%mkm_s
     mkm(2) = par%mkm_p
     mkm(3) = par%mkm_r
@@ -311,24 +317,25 @@ contains
     w_res = par%wres
     vev = par%v
     do i=1,5
-      if (w_res == 1 .and. wkm(i) == 0 .and. gkm(i) /= 0 ) then
+ if (w_res == 1 .and. wkm(i) == 0 .and. gkm(i) /= 0 ) then
         select case (i)
           case (1) !!! Scalar isosinglet
-            wkm(1) = (3 + gkm(14))*gkm(1)**2 /128.0_default/Pi * &
+            wkm(1) = (3 + gkm(14))*gkm(1)**2 /32.0_default/Pi * &
                  & mkm(1)**3 
             width(45) = wkm(1)
             write (*, "(1x,A,ES19.12)")  "Setting width: wkm_s =", wkm(1)
           case (2) !!! Scalar isoquintet
-            wkm(2) = gkm(2)**2 /256.0_default/Pi * mkm(2)**3 
+            wkm(2) = gkm(2)**2 /128.0_default/Pi * mkm(2)**3 
             width(46) = wkm(2)
             width(47) = wkm(2)
             width(48) = wkm(2)
+            width(49) = wkm(2)
             write (*, "(1x,A,ES19.12)")  "Setting width: wkm_p =", wkm(2)
           case (3) !!! Vector isotriplet
              wkm(3) = gkm(3)**2/48.0_default/Pi * mkm(3)
 !!            write (*, "(1x,A,ES19.12)")  "Setting width: wkm_r =", wkm(3)
           case (4) !!! Tensor isosinglet
-            wkm(4) = (3 + gkm(14))*gkm(4)**2 /3840.0_default/Pi * &
+            wkm(4) = (3 + gkm(14))*gkm(4)**2 /960.0_default/Pi * &
                  & mkm(4)**3 
             width(52) = wkm(4)
             width(56) = wkm(4)
@@ -338,10 +345,11 @@ contains
            write (*, "(1x,A,ES19.12)")  "Setting width: mkm_f =", mkm(4)
            write (*, "(1x,A,ES19.12)")  "Setting width: gkm_f =", gkm(4)
           case (5) !!! Tensor isoquintet
-            wkm(5) = gkm(5)**2 /7680.0_default/Pi * mkm(5)**3 
+            wkm(5) = gkm(5)**2 /3840.0_default/Pi * mkm(5)**3 
             width(53) = wkm(5)
             width(54) = wkm(5)
             width(55) = wkm(5)
+            width(59) = wkm(5)
             write (*, "(1x,A,ES19.12)")  "Setting width: wkm_t =", wkm(5)
         end select
       end if
@@ -385,10 +393,13 @@ contains
     gshh = - gkm(1) * gkm(14)
     gswwt = gkm(6) * g**3 / mass(24) / (16.0 * PI) 
     gszzt = gkm(6) * g**3 / costhw**3 / mass(23) /(16.0 * PI)
-    gpnww = - gkm(2) * mass(24) ** 2 / sqrt(12.0_default)
-    gpnzz = gkm(2) * mass(23) ** 2  / sqrt(3.0_default)
-    gpwz = gkm(2) * mass(23) ** 2  / 2.0_default
-    gpww = gkm(2) * mass(24) ** 2  / sqrt(2.0_default)
+    gpnww = - gkm(2) * mass(24) ** 2 / sqrt(6.0_default)
+    gpnzz = gkm(2) * mass(23) ** 2  * 2.0_default / sqrt(6.0_default)
+    gpsnww = gkm(2) * mass(24) ** 2 / sqrt(12.0_default)
+    gpsnzz = gkm(2) * mass(23) ** 2  / sqrt(12.0_default)
+    gpsnhh = gkm(2) * gkm(14) * sqrt(3.0_default)/ 2.0_default
+    gpwz = gkm(2) * mass(23) * mass(24)  / 2.0_default
+    gpww = gkm(2) * mass(24) ** 2  
     gfww = gkm(4) * mass(24) ** 2  / 2.0_default * (0)
     gfwwcf = gfww * gcf 
     gfzz = gkm(4) * mass(23) ** 2 / 2.0_default * (0)
@@ -418,13 +429,17 @@ contains
     gfshh = - gkm(4) * gkm(14) * (gcf -1 ) * (sw_ts)/sqrt(6.0_default)
     gfwwt = gkm(9) * g**3 / mass(24) / (32.0 * PI) 
     gfzzt = gkm(9) * g**3 / costhw**3 / mass(23) /(32.0 * PI)
-    gtnww = - gkm(5) * mass(24) ** 2 / 4.0_default / sqrt(3.0_default)
+    gtnww = - gkm(5) * mass(24) ** 2 / 2.0_default / sqrt(6.0_default)
     gtnwwcf = gtnww * gcf
-    gtnzz = gkm(5) * mass(23) ** 2 / 2.0_default / sqrt(3.0_default)
+    gtnzz = gkm(5) * mass(23) ** 2 / sqrt(6.0_default)
     gtnzzcf = gtnzz * gcf
-    gtwz = gkm(5) * mass(23) ** 2 / 4.0_default
+    gtsnww = gkm(5) * mass(24) ** 2 / 4.0_default / sqrt(3.0_default)
+    gtsnwwcf = gtsnww * gcf
+    gtsnzz = gkm(5) * mass(23) ** 2 / 4.0_default / sqrt(3.0_default)
+    gtsnzzcf = gtsnzz * gcf
+    gtwz = gkm(5) * mass(23) * mass(24) / 2.0_default / sqrt(2.0_default)
     gtwzcf = gtwz * gcf
-    gtww = gkm(5) * mass(24) ** 2 / 2.0_default / sqrt(2.0_default)
+    gtww = gkm(5) * mass(24) ** 2 / 2.0_default 
     gtwwcf = gtww * gcf
     gssww = 0
     gsszz = 0
