@@ -1,4 +1,4 @@
-! WHIZARD 2.2.7 Aug 11 2015
+! WHIZARD 2.2.8 Nov 22 2015
 ! 
 ! Copyright (C) 1999-2015 by 
 !     Wolfgang Kilian <kilian@physik.uni-siegen.de>
@@ -6,11 +6,14 @@
 !     Juergen Reuter <juergen.reuter@desy.de>
 !     
 !     with contributions from
-!     Fabian Bach <fabian.bach@desy.de>
+!     Fabian Bach <fabian.bach@t-online.de>
+!     Bijan Chokoufe <bijan.chokoufe@desy.de>
 !     Christian Speckner <cnspeckn@googlemail.com> 
+!     Soyoung Shim <soyoung.shim@desy.de>
+!     Florian Staub <florian.staub@cern.ch>  
 !     Christian Weiss <christian.weiss@desy.de>
 !     and Hans-Werner Boschmann, Felix Braam, 
-!     Sebastian Schmidt, Daniel Wiesler 
+!     Sebastian Schmidt, So-young Shim, Daniel Wiesler 
 !
 ! WHIZARD is free software; you can redistribute it and/or modify it
 ! under the terms of the GNU General Public License as published by 
@@ -116,7 +119,12 @@ module interactions
           interaction_get_n_matrix_elements
      procedure :: get_norm => interaction_get_norm
      procedure :: get_quantum_numbers => interaction_get_quantum_numbers
-     procedure :: get_matrix_element => interaction_get_matrix_element
+     generic :: get_matrix_element => get_matrix_element_single
+     generic :: get_matrix_element => get_matrix_element_array
+     procedure :: get_matrix_element_single => &
+        interaction_get_matrix_element_single
+     procedure :: get_matrix_element_array => &
+        interaction_get_matrix_element_array
      generic :: set_matrix_element => interaction_set_matrix_element_qn, &
           interaction_set_matrix_element_all, &
           interaction_set_matrix_element_array, &
@@ -559,12 +567,18 @@ contains
     qn = int%state_matrix%get_quantum_numbers (i)
   end function interaction_get_quantum_numbers
 
-  function interaction_get_matrix_element (int, i) result (me)
+  function interaction_get_matrix_element_single (int, i) result (me)
     class(interaction_t), intent(in) :: int
     complex(default) :: me
     integer, intent(in) :: i
     me = int%state_matrix%get_matrix_element (i)
-  end function interaction_get_matrix_element
+  end function interaction_get_matrix_element_single
+
+  function interaction_get_matrix_element_array (int) result (me)
+    complex(default), dimension(:), allocatable :: me
+    class(interaction_t), intent(in) :: int
+    me = int%state_matrix%get_matrix_element ()
+  end function interaction_get_matrix_element_array
 
   subroutine interaction_set_matrix_element_qn (int, qn, val)
     class(interaction_t), intent(inout) :: int
