@@ -1,4 +1,4 @@
-! WHIZARD 2.2.7 Aug 11 2015
+! WHIZARD 2.2.8 Nov 22 2015
 ! 
 ! Copyright (C) 1999-2015 by 
 !     Wolfgang Kilian <kilian@physik.uni-siegen.de>
@@ -6,11 +6,14 @@
 !     Juergen Reuter <juergen.reuter@desy.de>
 !     
 !     with contributions from
-!     Fabian Bach <fabian.bach@desy.de>
+!     Fabian Bach <fabian.bach@t-online.de>
+!     Bijan Chokoufe <bijan.chokoufe@desy.de>
 !     Christian Speckner <cnspeckn@googlemail.com> 
+!     Soyoung Shim <soyoung.shim@desy.de>
+!     Florian Staub <florian.staub@cern.ch>  
 !     Christian Weiss <christian.weiss@desy.de>
 !     and Hans-Werner Boschmann, Felix Braam, 
-!     Sebastian Schmidt, Daniel Wiesler 
+!     Sebastian Schmidt, So-young Shim, Daniel Wiesler 
 !
 ! WHIZARD is free software; you can redistribute it and/or modify it
 ! under the terms of the GNU General Public License as published by 
@@ -47,7 +50,7 @@ module unit_tests
   public :: assert
   public:: assert_equal
   interface assert_equal
-     module procedure assert_equal_real, assert_equal_integer
+     module procedure assert_equal_real, assert_equal_complex, assert_equal_integer
   end interface
   public :: nearly_equal
   public:: vanishes
@@ -249,10 +252,10 @@ contains
 
   subroutine assert_equal_real (unit, lhs, rhs, description, &
                                 abs_smallness, rel_smallness)
-    real(default), intent(in), optional :: abs_smallness, rel_smallness
     integer, intent(in) :: unit
     real(default), intent(in) :: lhs, rhs
     character(*), intent(in), optional :: description
+    real(default), intent(in), optional :: abs_smallness, rel_smallness
     logical :: ok
     ok = nearly_equal (lhs, rhs, abs_smallness, rel_smallness)
     if (.not. ok) then
@@ -266,6 +269,35 @@ contains
     end if
   end subroutine assert_equal_real
 
+  subroutine assert_equal_complex (unit, lhs, rhs, description, &
+                                abs_smallness, rel_smallness)
+    integer, intent(in) :: unit
+    complex(default), intent(in) :: lhs, rhs
+    character(*), intent(in), optional :: description
+    real(default), intent(in), optional :: abs_smallness, rel_smallness
+    logical :: ok
+    ok = nearly_equal (real(lhs), real(rhs), abs_smallness, rel_smallness)
+    if (.not. ok) then
+       if (present(description)) then
+          write (unit, "(A," // FMT_19 // ",A," // FMT_19 // ")") &
+               "* FAIL: " // description // ": ", real(lhs), " /= ", real(rhs)
+       else
+          write (unit, "(A," // FMT_19 // ",A," // FMT_19 // ")") &
+               "* FAIL: Assertion error: ", real(lhs), " /= ", real(rhs)
+       end if
+    end if
+    ok = nearly_equal (aimag(lhs), aimag(rhs), abs_smallness, rel_smallness)
+    if (.not. ok) then
+       if (present(description)) then
+          write (unit, "(A," // FMT_19 // ",A," // FMT_19 // ")") &
+               "* FAIL: " // description // ": ", aimag(lhs), " /= ", aimag(rhs)
+       else
+          write (unit, "(A," // FMT_19 // ",A," // FMT_19 // ")") &
+               "* FAIL: Assertion error: ", aimag(lhs), " /= ", aimag(rhs)
+       end if
+    end if
+  end subroutine assert_equal_complex
+
   subroutine assert_equal_integer (unit, lhs, rhs, description)
     integer, intent(in) :: unit
     integer, intent(in) :: lhs, rhs
