@@ -1,4 +1,4 @@
-! WHIZARD 2.2.7 Aug 11 2015
+! WHIZARD 2.2.8 Nov 22 2015
 ! 
 ! Copyright (C) 1999-2015 by 
 !     Wolfgang Kilian <kilian@physik.uni-siegen.de>
@@ -6,11 +6,14 @@
 !     Juergen Reuter <juergen.reuter@desy.de>
 !     
 !     with contributions from
-!     Fabian Bach <fabian.bach@desy.de>
+!     Fabian Bach <fabian.bach@t-online.de>
+!     Bijan Chokoufe <bijan.chokoufe@desy.de>
 !     Christian Speckner <cnspeckn@googlemail.com> 
+!     Soyoung Shim <soyoung.shim@desy.de>
+!     Florian Staub <florian.staub@cern.ch>  
 !     Christian Weiss <christian.weiss@desy.de>
 !     and Hans-Werner Boschmann, Felix Braam, 
-!     Sebastian Schmidt, Daniel Wiesler 
+!     Sebastian Schmidt, So-young Shim, Daniel Wiesler 
 !
 ! WHIZARD is free software; you can redistribute it and/or modify it
 ! under the terms of the GNU General Public License as published by 
@@ -605,7 +608,8 @@ contains
     type(flavor_t), dimension(:,:), allocatable :: flv
     logical, dimension(:), allocatable :: stable
     real(default), dimension(:), allocatable :: m_prod, m_dec
-    integer :: i
+    !!! !!! !!! Workaround for ifort 16.0 standard-semantics bug
+    integer :: i, j
     call decay%init (model, process%get_id (), process%get_n_terms ())
     do i = 1, size (decay%term_config)
        if (present (process_instance)) then
@@ -616,12 +620,24 @@ contains
           call process%get_term_flv_out (i, flv)
        end if
        allocate (m_prod (size (flv(:,1)%get_mass ())))
-       m_prod = flv(:,1)%get_mass ()
+       !!! !!! !!! Workaround for ifort 16.0 standard-semantics bug
+       do j = 1, size (flv(:,1)%get_mass ())
+          m_prod(j) = flv(j,1)%get_mass ()
+       end do
+       !!! m_prod = flv(:,1)%get_mass ()
        call flv%set_model (model)
        allocate (m_dec (size (flv(:,1)%get_mass ())))
-       m_dec = flv(:,1)%get_mass ()
+       !!! !!! !!! Workaround for ifort 16.0 standard-semantics bug       
+       do j = 1, size (flv(:,1)%get_mass ())
+          m_dec(j) = flv(j,1)%get_mass ()
+       end do
+       !!! m_dec = flv(:,1)%get_mass ()
        allocate (stable (size (flv, 1)))
-       stable = flv(:,1)%is_stable ()
+       !!! !!! !!! Workaround for ifort 16.0 standard-semantics bug       
+       do j = 1, size (flv, 1)
+          stable(j) = flv(j,1)%is_stable ()
+       end do
+       !!! stable = flv(:,1)%is_stable ()
        call check_masses ()
        call decay%init_term (i, flv, stable, model, process_stack)
        deallocate (flv, stable, m_prod, m_dec)
