@@ -6,12 +6,12 @@ if test -f OCAML_FLAG -a -f OPENLOOPS_FLAG; then
     ./run_whizard.sh @script@ --no-logging
     rc=$?; if [ $rc != 0 ]; then exit $rc; fi
     @python_bin@ @share_dir@/compare-integrals-multi.py $s \
-      @share_dir@/extra_integration_results.dat #&>> $s.run.log
+      @share_dir@/extra_integration_results.dat
     rc=$?; if [ $rc != 0 ]; then exit $rc; fi
     @python_bin@ @share_dir@/compare-methods.py $s
     rc=$?; if [ $rc != 0 ]; then exit $rc; fi
   else
     echo "|=============================================================================|"
-    echo "No O'Mega matrix elements available"
+    echo "No O'Mega and/or OpenLoops matrix elements available"
     exit 77
 fi
