@@ -4,10 +4,14 @@ echo "Running script $0"
 if test -f OCAML_FLAG -a -f PYTHIA6_FLAG; then
     ./run_whizard.sh @script@ --no-logging
     script=`basename @script@`
-    echo "Partial contents of ${script}a.debug:" >> $script.log
+    echo "Contents of ${script}a.debug:" >> $script.log
     cat ${script}a.debug >> $script.log
-    echo "Partial contents of ${script}b.debug:" >> $script.log
+    echo "Contents of ${script}b.debug:" >> $script.log
     cat ${script}b.debug >> $script.log
+    echo "Contents of ${script}c.debug:" >> $script.log
+    cat ${script}c.debug >> $script.log
+    echo "Contents of ${script}d.debug:" >> $script.log
+    cat ${script}d.debug >> $script.log
     diff ref-output/$script.ref $script.log
 else
     echo "|=============================================================================|"
